<?php
// Add menu item under Settings menu
add_action('admin_menu', 'ai_images_settings_menu');

function ai_images_settings_menu()
{
  add_options_page(
    'AI Images Settings',           // Page title
    'AI Images',                    // Menu title
    'manage_options',               // Capability
    'ai-images-settings',           // Menu slug
    'ai_images_settings_page'       // Callback function
  );
}

function ai_images_settings_page()
{
?>
  <div class="wrap">
    <h1>AI Images Settings</h1>
    <form method="post" action="options.php">
      <?php
      settings_fields('ai_images_settings');
      do_settings_sections('ai-images-settings');
      submit_button('Save Settings');
      ?>
    </form>

    <form method="post" action="">
      <?php
      submit_button('Generate Random Image', 'secondary', 'generate_random_image', false);
      ?>
    </form>
  </div>
<?php
}

add_action('admin_init', 'handle_generate_random_image');

function handle_generate_random_image()
{
  if (isset($_POST['generate_random_image'])) {
    $prompt = 'Generate a random image';
    $post_title_slug = sanitize_title('random_image_' . time()); // Unique identifier

    // Call your existing function to generate the image
    $image_file = generate_dalle_image($prompt, $post_title_slug);

    if ($image_file) {
      // Insert the generated image into the media library
      $attachment_id = dalle_insert_attachment($image_file, 0);
      if ($attachment_id) {
        echo '<div class="notice notice-success"><p>Random image generated and saved successfully.</p></div>';
      } else {
        echo '<div class="notice notice-error"><p>Error saving generated image to media library.</p></div>';
      }
    } else {
      echo '<div class="notice notice-error"><p>Error generating image.</p></div>';
    }
  }
}



add_action('admin_init', 'ai_images_settings_init');

function ai_images_settings_init()
{
  // Register a setting and add a field for OPENAI_API_KEY
  register_setting('ai_images_settings', 'openai_api_key');
  add_settings_field(
    'openai_api_key',
    'OpenAI API Key',
    'ai_images_openai_api_key_callback',
    'ai-images-settings',
    'ai_images_settings_section'
  );

  // Register a setting and add a field for Custom Instructions
  register_setting('ai_images_settings', 'custom_instructions');
  add_settings_field(
    'custom_instructions',
    'Custom Instructions',
    'ai_images_custom_instructions_callback',
    'ai-images-settings',
    'ai_images_settings_section'
  );

  // Add a section if needed
  add_settings_section(
    'ai_images_settings_section',
    'Settings Section',
    'ai_images_settings_section_callback',
    'ai-images-settings'
  );
}

// Field callback functions

function ai_images_openai_api_key_callback()
{
  $value = get_option('openai_api_key');
  echo '<input type="text" id="openai_api_key" name="openai_api_key" value="' . esc_attr($value) . '" />';
}

function ai_images_custom_instructions_callback()
{
  $value = get_option('custom_instructions');
  echo '<textarea id="custom_instructions" name="custom_instructions" rows="5" cols="50">' . esc_textarea($value) . '</textarea>';
}

function ai_images_settings_section_callback()
{
  echo '<p>Enter your API key and custom instructions below:</p>';
}

// Optionally, validate and sanitize input before saving
function ai_images_sanitize_api_key($input)
{
  return sanitize_text_field($input);
}

function ai_images_sanitize_instructions($input)
{
  return sanitize_textarea_field($input);
}

// Hook into the 'admin_init' action hook
add_filter('sanitize_option_openai_api_key', 'ai_images_sanitize_api_key');
add_filter('sanitize_option_custom_instructions', 'ai_images_sanitize_instructions');
