<?php
function generate_dalle_image($text, $post_title_slug)
{
    // Retrieve settings values
    $openai_api_key = get_option('openai_api_key');
    $custom_instructions = get_option('custom_instructions');

    // Prepare body for API request
    $body = json_encode([
        'prompt' => $text . ' ' . $custom_instructions,
        'model' => 'dall-e-3',
    ]);

    $headers = [
        'Content-Type' => 'application/json',
        'Authorization' => 'Bearer ' . $openai_api_key,
    ];

    $response = wp_remote_post('https://api.openai.com/v1/images/generations', [
        'body'    => $body,
        'headers' => $headers,
        'data_format' => 'body',
        'timeout' => 30
    ]);

    if (is_wp_error($response)) {
        return false;
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);
    
    if (empty($data['data'][0]['url'])) {
        return false;
    }

    $image_url = $data['data'][0]['url'];
    return dalle_download_image($image_url, $post_title_slug);
}

function dalle_download_image($image_url, $post_title_slug)
{
    $upload_dir = wp_upload_dir();
    $image_data = file_get_contents($image_url);

    if (!$image_data) {
        return false;
    }

    $filename = $post_title_slug . '.png';
    if (wp_mkdir_p($upload_dir['path'])) {
        $file = $upload_dir['path'] . '/' . $filename;
    } else {
        $file = $upload_dir['basedir'] . '/' . $filename;
    }

    file_put_contents($file, $image_data);

    return $file;
}

function dalle_insert_attachment($file, $post_id)
{   
    $filename = basename($file);
    $attachment = [
        'post_mime_type' => 'image/jpeg',
        'post_title' => sanitize_file_name($filename),
        'post_content' => '',
        'post_status' => 'inherit'
    ];
    $attach_id = wp_insert_attachment($attachment, $file);

    if ($post_id == 0) {
        $attach_data = wp_generate_attachment_metadata($attach_id, $file);
    } else {
        $attach_id = wp_insert_attachment($attachment, $file, $post_id);
    }

    require_once(ABSPATH . 'wp-admin/includes/image.php');

    $attach_data = wp_generate_attachment_metadata($attach_id, $file);
    wp_update_attachment_metadata($attach_id, $attach_data);


    return $attach_id;
}
